package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.GoodsCart;
import com.ruoyi.system.service.IGoodsCartService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 购物车Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/GoodsCart")
public class GoodsCartController extends BaseController
{
    @Autowired
    private IGoodsCartService goodsCartService;

    /**
     * 查询购物车列表
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsCart:list')")
    @GetMapping("/list")
    public TableDataInfo list(GoodsCart goodsCart)
    {
        startPage();
        List<GoodsCart> list = goodsCartService.selectGoodsCartList(goodsCart);
        return getDataTable(list);
    }

    /**
     * 导出购物车列表
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsCart:export')")
    @Log(title = "购物车", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GoodsCart goodsCart)
    {
        List<GoodsCart> list = goodsCartService.selectGoodsCartList(goodsCart);
        ExcelUtil<GoodsCart> util = new ExcelUtil<GoodsCart>(GoodsCart.class);
        util.exportExcel(response, list, "购物车数据");
    }

    /**
     * 获取购物车详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsCart:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(goodsCartService.selectGoodsCartById(id));
    }

    /**
     * 新增购物车
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsCart:add')")
    @Log(title = "购物车", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GoodsCart goodsCart)
    {
        return toAjax(goodsCartService.insertGoodsCart(goodsCart));
    }

    /**
     * 修改购物车
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsCart:edit')")
    @Log(title = "购物车", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GoodsCart goodsCart)
    {
        return toAjax(goodsCartService.updateGoodsCart(goodsCart));
    }

    /**
     * 删除购物车
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsCart:remove')")
    @Log(title = "购物车", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(goodsCartService.deleteGoodsCartByIds(ids));
    }
}
